@@ -98,6 +98,9 @@ edit_apsimx <- function(file, src.dir = ".", wrt.dir = NULL,
   ## Parse apsimx file (JSON)
   apsimx_json <- jsonlite::read_json(file.path(src.dir, file))
   
+  if(!missing(parm.path) && node != "Other")
+    stop("When parm.path is supplied node should be 'Other'", call. = FALSE)
+  
   ## Where is the 'Core' simulation?
   wcore <- grep("Core.Simulation", apsimx_json$Children)
 
@@ -107,18 +110,43 @@ edit_apsimx <- function(file, src.dir = ".", wrt.dir = NULL,
       str_list(apsimx_json)
       stop("more than one simulation found and no root node label has been specified \n select one of the children names above")   
     }else{
+      if(length(root) > 3)
+        stop("At the moment 3 is the maximum length for root", call. = TRUE)
+      
       if(length(root) == 1){
         wcore1 <- grep(as.character(root), apsimx_json$Children)
         if(length(wcore1) == 0 || length(wcore1) > 1)
           stop("no root node label found or root is not unique")
         parent.node <- apsimx_json$Children[[wcore1]]$Children
-      }else{
+      }
+      if(length(root) == 2){
         root.node.0.names <- sapply(apsimx_json$Children, function(x) x$Name)
         wcore1 <- grep(as.character(root[1]), root.node.0.names)
+        if(length(wcore1) == 0 || length(wcore1) > 1)
+          stop("no root node label in position 1 found or root is not unique")
+        root.node.0 <- apsimx_json$Children[[wcore1]]
+        root.node.0.child.names <- sapply(root.node.0$Children, function(x) x$Name)  
+        wcore2 <- grep(as.character(root[2]), root.node.0.child.names)
+        if(length(wcore2) == 0 || length(wcore2) > 1)
+          stop("no root node label in position 2 found or root is not unique")
+        parent.node <- apsimx_json$Children[[wcore1]]$Children[[wcore2]]$Children        
+      }
+      if(length(root) == 3){
+        root.node.0.names <- sapply(apsimx_json$Children, function(x) x$Name)
+        wcore1 <- grep(as.character(root[1]), root.node.0.names)
+        if(length(wcore1) == 0 || length(wcore1) > 1)
+          stop("no root node label in position 1 found or root is not unique")
         root.node.0 <- apsimx_json$Children[[wcore1]]
         root.node.0.child.names <- sapply(root.node.0$Children, function(x) x$Name)
         wcore2 <- grep(as.character(root[2]), root.node.0.child.names)
-        parent.node <- apsimx_json$Children[[wcore1]]$Children[[wcore2]]$Children
+        if(length(wcore2) == 0 || length(wcore2) > 1)
+          stop("no root node label in position 2 found or root is not unique")
+        root.node.1 <- apsimx_json$Children[[wcore1]]$Children[[wcore2]]
+        root.node.1.child.names <- sapply(root.node.1$Children, function(x) x$Name)  
+        wcore3 <- grep(as.character(root[3]), root.node.1.child.names)
+        if(length(wcore3) == 0 || length(wcore3) > 1)
+          stop("no root node label in position 3 found or root is not unique")
+        parent.node <- apsimx_json$Children[[wcore1]]$Children[[wcore2]]$Children[[wcore3]]$Children        
       }
     }
   }else{
@@ -131,9 +159,12 @@ edit_apsimx <- function(file, src.dir = ".", wrt.dir = NULL,
     parm <- match.arg(parm, choices = parm.choices, several.ok = TRUE)
     ## Find what the 'Start' and 'End' are actually called
     ## Find the 'Clock'
-    wlc <- function(x) grepl("Clock", x$Name)
+    wlc <- function(x) grepl("Models.Clock", x$`$type`, ignore.case = TRUE)
     wlcl <- sapply(parent.node, FUN = wlc)
     
+    if(sum(wlcl) < 1)
+      stop("Clock not found", call. = FALSE)
+    
     start <- grep("Start", names(parent.node[wlcl][[1]]), 
                   ignore.case = TRUE, value = TRUE)
     
@@ -157,24 +188,45 @@ edit_apsimx <- function(file, src.dir = ".", wrt.dir = NULL,
         parent.node[wlcl][[1]][end] <- value[2]
       }
     }
-    apsimx_json$Children[[1]]$Children <- parent.node
+    ## The code below is not needed, I think
+    # if(missing(root)){
+    #   apsimx_json$Children[[1]]$Children <- parent.node  
+    # }else{
+    #   if(length(root) == 1){
+    #     apsimx_json$Children[[wcore1]]$Children <- parent.node  
+    #   }else{
+    #     apsimx_json$Children[[wcore1]]$Children[[wcore2]]$Children <- parent.node
+    #   }
+    # }
   }
   
   ## Edit the met file
   if(node == "Weather"){
-    wlw <- function(x) grepl("Weather", x$Name)
+    wlw <- function(x) grepl("Models.Climate.Weather|Models.Weather", x$`$type`)
     wlwl <- sapply(parent.node, FUN = wlw)
+    
+    if(sum(wlwl) < 1)
+      stop("Weather node not found", call. = FALSE)
+    
     parent.node[wlwl][[1]]$FileName <- value
   }
   
   ## Extract 'Core' simulation
   wcz <- grepl("Models.Core.Zone", parent.node)
+  
+  if(sum(wcz) < 1)
+    stop("Models.Core.Zone not found", call. = FALSE)
+  
   core.zone.node <- parent.node[wcz][[1]]$Children
   
   ## Edit the soil
   if(node == "Soil"){
     ## Extract soil
     wsn <- grepl("Models.Soils.Soil", core.zone.node)
+    
+    if(sum(wsn) < 1)
+      stop("Models.Soils.Soil not found", call. = FALSE)
+    
     soil.node <- core.zone.node[wsn]
     
     soil.node0 <- soil.node[[1]]$Children
@@ -560,9 +612,13 @@ edit_apsimx <- function(file, src.dir = ".", wrt.dir = NULL,
       ## otherwise an error would have been triggered before
       if(length(root) == 1){
         apsimx_json$Children[[wcore1]]$Children <- parent.node 
-      }else{
+      }
+      if(length(root) == 2){
         apsimx_json$Children[[wcore1]]$Children[[wcore2]]$Children <- parent.node 
       }
+      if(length(root) == 3){
+        apsimx_json$Children[[wcore1]]$Children[[wcore2]]$Children[[wcore3]]$Children <- parent.node 
+      }
     }else{
       apsimx_json$Children[[wcore]]$Children <- parent.node 
     }    
