@@ -1,5 +1,5 @@
 #'
-#' This function requires the \CRANpkg{nasapower} package.
+#' This function requires the \CRANpkg{nasapower} package version 4.0.0.
 #'
 #' @title Get NASA-POWER data for an APSIM met file
 #' @description Uses \code{\link[nasapower]{get_power}} from the \CRANpkg{nasapower} package to download data to create an APSIM met file.
@@ -18,13 +18,15 @@
 #' require(nasapower)
 #' ## This will not write a file to disk
 #' pwr <- get_power_apsim_met(lonlat = c(-93,42), dates = c("2012-01-01","2012-12-31"))
-#' ## There are some missing values
+#' ## Let's insert a missing value
+#' pwr[100, "radn"] <- NA
 #' summary(pwr)
 #' ## Check the met file 
 #' check_apsim_met(pwr)
 #' ## Impute using linear interpolation
 #' pwr.imptd <- impute_apsim_met(pwr, verbose = TRUE)
 #' summary(pwr.imptd)
+#' check_apsim_met(pwr.imptd)
 #' }
 #' 
 
@@ -59,7 +61,7 @@ get_power_apsim_met <- function(lonlat, dates, wrt.dir = ".", filename = NULL){
                                                "T2M_MAX", "T2M_MIN",
                                                "PRECTOTCORR", "RH2M", "WS2M"))
   
-  names(pwr) <- c("year", "day", "radn", "maxt", "mint", "rain", "rh", "wind_speed")
+  names(pwr) <- c("year", "day", "radn", "maxt", "mint", "rain", "rh", "windspeed")
   units <- c("()", "()", "(MJ/m2/day)", "(oC)", "(oC)", "(mm)", "(%)", "(m/s)")
   
   comments <- paste("!data from nasapower R package. retrieved: ", Sys.time())
